@@ -115,20 +115,39 @@ class Jira(AtlassianRestAPI):
         url = 'rest/api/2/user?username={0}'.format(username)
         return self.put(url, data=data)
 
-    def user_create(self, username, email, password, display_name):
+    def user_update_username(self, old_username, new_username):
+        """
+        Update username
+        :param old_username:
+        :param new_username:
+        :return:
+        """
+        data = {"name": new_username}
+        return self.user_update(old_username, data=data)
+
+    def user_create(self, username, email, display_name, password = None, notification = None):
+
         """
         Create a user in Jira
         :param username:
         :param email:
-        :param password:
         :param display_name:
+        :param password: OPTIONAL: If a password is not set, a random password is generated.
+        :param notification: OPTIONAL: Sends the user an email confirmation that they have been added to Jira. Default:false.
         :return:
         """
         log.warning('Creating user {}'.format(display_name))
-        data = {'password': password,
+        data = {'name': username,
                 'emailAddress': email,
-                'displayName': display_name,
-                'name': username}
+                'displayName': display_name}
+        if password is not None:
+            data['password'] = password
+        else:
+            data['notification'] = True
+        if notification is not None:
+            data['notification'] = True
+        if notification is False:
+            data['notification'] = False
         return self.post('rest/api/2/user', data=data)
 
     def user_properties(self, username):
@@ -1371,17 +1390,25 @@ class Jira(AtlassianRestAPI):
 
     def tempo_holiday_get_schemes(self):
         """
-        Provide a holiday scheme
+        Provide a holiday schemes
         :return:
         """
         url = 'rest/tempo-core/2/holidayschemes/'
         return self.get(url)
 
-    def tempo_holiday_get_scheme_members(self, scheme_id):
+    def tempo_holiday_get_scheme_info(self, scheme_id):
         """
         Provide a holiday scheme
         :return:
         """
+        url = 'rest/tempo-core/2/holidayschemes/{}'.format(scheme_id)
+        return self.get(url)
+
+    def tempo_holiday_get_scheme_members(self, scheme_id):
+        """
+        Provide a holiday scheme members
+        :return:
+        """
         url = 'rest/tempo-core/2/holidayschemes/{}/members'.format(scheme_id)
         return self.get(url)
 
@@ -1394,6 +1421,28 @@ class Jira(AtlassianRestAPI):
         data = {'id': scheme_id}
         return self.put(url, data=data)
 
+    def tempo_holiday_scheme_set_default(self, scheme_id):
+        """
+        Set as default the holiday scheme
+        :param scheme_id:
+        :return:
+        """
+        # @deprecated available in private mode the 1 version
+        # url = 'rest/tempo-core/1/holidayscheme/setDefault/{}'.format(scheme_id)
+
+        url = 'rest/tempo-core/2/holidayscheme/setDefault/{}'.format(scheme_id)
+        data = {'id': scheme_id}
+        return self.post(url, data=data)
+
+    def tempo_workload_scheme_get_members(self, scheme_id):
+        """
+        Provide a workload scheme members
+        :param scheme_id:
+        :return:
+        """
+        url = 'rest/tempo-core/1/workloadscheme/users/{}'.format(scheme_id)
+        return self.get(url)
+
     def tempo_timesheets_get_configuration(self):
         """
         Provide the configs of timesheets
